@@ -2,7 +2,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::HARTZELL;
-$Dist::Zilla::PluginBundle::HARTZELL::VERSION = '0.009';
+$Dist::Zilla::PluginBundle::HARTZELL::VERSION = '0.010';
 # ABSTRACT: My standard dzil config.
 
 
@@ -189,6 +189,7 @@ sub configure {
                      'ExecDir',            # core
                      'ShareDir',           # core
                      [ 'MakeMaker' => { eumm_version => '6.17', default_jobs => 9 } ], # core
+                     'CPANFile',
 
                      # copy files from build back to root for inclusion in VCS
                      [ CopyFilesFromBuild => {
@@ -202,7 +203,7 @@ sub configure {
                      # before release
                      [ 'Git::Check' =>
                        {
-                        allow_dirty => [qw/dist.ini Changes README.pod/]
+                        allow_dirty => [qw/dist.ini Changes README.pod cpanfile/]
                        }
                      ],
                      'CheckMetaResources',
@@ -252,7 +253,7 @@ Dist::Zilla::PluginBundle::HARTZELL - My standard dzil config.
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -341,6 +342,7 @@ dist.ini:
    [ExecDir]           ; include 'bin/*' as executables
    [ShareDir]          ; include 'share/' for File::ShareDir
    [Module::Build]     ; create Build.PL
+   [CPANFile]          ; build a cpanfile
  
    ; copy META.json back to repo dis
    [CopyFilesFromBuild]
@@ -354,6 +356,7 @@ dist.ini:
    allow_dirty = dist.ini
    allow_dirty = Changes
    allow_dirty = README.pod
+   allow_dirty = cpanfile
  
    [CheckMetaResources]     ; ensure META has 'resources' data
    [CheckPrereqsIndexed]    ; ensure prereqs are on CPAN
